@@ -93,7 +93,9 @@ class MarketMaker:
             if self.redeem_threshold is not None and model_state.inventory.liquidity_incentives.value > self.redeem_threshold:
                 redeem = self.market_instruction_builder.build_redeem_instructions()
 
-            (payer + cancellations + place_orders + crank + settle + redeem).execute(context)
+            # Don't bother if we have no orders to change
+            if len(cancellations.instructions) + len(place_orders.instructions) > 0:
+                (payer + cancellations + place_orders + crank + settle + redeem).execute(context)
 
             self.pulse_complete.on_next(datetime.now())
         except (mango.RateLimitException, mango.NodeIsBehindException, mango.BlockhashNotFoundException, mango.FailedToFetchBlockhashException) as common_exception:
