@@ -44,14 +44,18 @@ class RoundToLotSizeElement(Element):
         for order in orders:
             new_price: Decimal = model_state.market.lot_size_converter.round_quote(order.price)
             new_quantity: Decimal = model_state.market.lot_size_converter.round_base(order.quantity)
-            new_order: mango.Order = order
-            if (new_order.price != new_price) or (new_order.quantity != new_quantity):
-                new_order = new_order.with_price(new_price).with_quantity(new_quantity)
-                self.logger.debug(f"""Order change - price is now aligned to lot size:
+            new_order: mango.Order = order.with_price(new_price).with_quantity(new_quantity)
+            if new_order.price == 0 or new_order.quantity == 0:
+                self.logger.debug(f"""Order removed - price or quantity rounded to zero:
     Old: {order}
     New: {new_order}""")
-
-            new_orders += [new_order]
+            elif (order.price != new_order.price) or (order.quantity != new_order.quantity):
+                new_orders += [new_order]
+                self.logger.debug(f"""Order change - price and quantity now aligned to lot size:
+    Old: {order}
+    New: {new_order}""")
+            else:
+                new_orders += [order]
 
         return new_orders
 
