@@ -96,13 +96,13 @@ class SpotMarketInstructionBuilder(MarketInstructionBuilder):
             return CombinableInstructions.empty()
 
         base_slot: GroupSlot = self.group.slot_by_instrument(self.spot_market.base)
-        if base_slot.base_token_info is None:
+        if base_slot.base_token_bank is None:
             raise Exception(
                 f"No token info for base instrument {self.spot_market.base.symbol} in group {self.group.address}")
-        base_rootbank = base_slot.base_token_info.load_root_bank(self.context)
+        base_rootbank = base_slot.base_token_bank.ensure_root_bank(self.context)
         base_nodebank = base_rootbank.pick_node_bank(self.context)
 
-        quote_rootbank = self.group.shared_quote.load_root_bank(self.context)
+        quote_rootbank = self.group.shared_quote.ensure_root_bank(self.context)
         quote_nodebank = quote_rootbank.pick_node_bank(self.context)
         return build_spot_settle_instructions(self.context, self.wallet, self.account,
                                               self.raw_market, self.group, self.open_orders_address,
